<?php
/**
 * Database configuration using Eloquent ORM.
 *
 * @package ServiceEZ
 * @subpackage Database
 * @since 1.0.0
 */

namespace ServiceEZ\Database\Migrations;

use ServiceEZ\Interfaces\Migration;
use Prappo\WpEloquent\Database\Capsule\Manager as Capsule;
use Prappo\WpEloquent\Support\Facades\Schema;

/**
 * Coupons migration class.
 *
 * @package ServiceEZ
 * @subpackage Database
 * @since 1.0.0
 */
class Coupons implements Migration {
	/**
	 * Up method.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public static function up() {
		if ( Capsule::schema()->hasTable( 'serviceez_coupons' ) ) {
			return;
		}
		Schema::create(
			'serviceez_coupons',
			function ( $table ) {
				$table->id();
				$table->string( 'code' )->unique();
				$table->decimal( 'discount', 5, 2 );
				$table->enum( 'type', array( 'percentage', 'fixed' ) );
				$table->enum( 'validity_type', array( 'forever', 'custom' ) );
				$table->timestamp( 'valid_until' )->nullable();
				$table->timestamps();
			}
		);
	}

	/**
	 * Down method.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public static function down() {
		Capsule::schema()->dropIfExists( 'serviceez_coupons' );
	}
}
