<?php
/**
 * Orders migration class.
 *
 * @package ServiceEZ
 * @subpackage Database
 * @since 1.0.0
 */

namespace ServiceEZ\Database\Migrations;

use ServiceEZ\Interfaces\Migration;
use Prappo\WpEloquent\Database\Schema\Blueprint;
use Prappo\WpEloquent\Support\Facades\Schema;

/**
 * Orders migration class.
 *
 * @package ServiceEZ
 * @subpackage Database
 * @since 1.0.0
 */
class Orders implements Migration {
	/**
	 * Up method.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public static function up() {
		if ( Schema::hasTable( 'serviceez_orders' ) ) {
			return;
		}
		Schema::create(
			'serviceez_orders',
			function ( Blueprint $table ) {
				$table->id();
				$table->unsignedBigInteger( 'client_id' );
				$table->unsignedBigInteger( 'service_id' );
				$table->string( 'order_status' );
				$table->string( 'payment_status' );
				$table->string( 'payment_method' );
				$table->decimal( 'total_amount', 10, 2 );
				$table->json( 'data' );
				$table->timestamps();
				$table->foreign( 'client_id' )->references( 'id' )->on( 'serviceez_clients' )->onDelete( 'cascade' );
				$table->foreign( 'service_id' )->references( 'id' )->on( 'serviceez_services' )->onDelete( 'cascade' );
			}
		);
	}

	/**
	 * Down method.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public static function down() {
		Schema::dropIfExists( 'serviceez_orders' );
	}
}
