<?php
/**
 * Database configuration using Eloquent ORM.
 *
 * @package ServiceEZ
 * @subpackage Database
 * @since 1.0.0
 */

namespace ServiceEZ\Database\Migrations;

use ServiceEZ\Interfaces\Migration;
use Prappo\WpEloquent\Database\Capsule\Manager as Capsule;
use Prappo\WpEloquent\Database\Schema\Blueprint;
use Prappo\WpEloquent\Support\Facades\Schema;

/**
 * Class Services
 *
 * Represents the migration for creating the 'serviceez_services' table.
 *
 * @package ServiceEZ\Database\Migrations
 */
class Services implements Migration {

	/**
	 * Table name for the migration.
	 *
	 * @var string
	 */
	private static $table = 'serviceez_services';

	/**
	 * Run the migrations.
	 */
	public static function up() {
		if ( Capsule::schema()->hasTable( self::$table ) ) {
			return;
		}
		Capsule::schema()->create(
			self::$table,
			function ( Blueprint $table ) {
				$table->id();
				$table->string( 'service_name' );
				$table->string( 'service_type' );
				$table->json( 'data' );
				$table->string( 'product_id' )->nullable();
				$table->json( 'product_data' )->nullable();
				$table->timestamps();
			}
		);
	}

	/**
	 * Reverse the migrations.
	 */
	public static function down() {
		Schema::dropIfExists( self::$table );
	}
}
