<?php

namespace ServiceEZ\Controllers\Messages;

use ServiceEZ\Models\Message;
use ServiceEZ\Models\Client;

class Actions {
	public function get_messages( \WP_REST_Request $request ) {
		$sender_id   = absint( $request->get_header( 'X-User-ID' ) );
		$receiver_id = absint( $request->get_param( 'id' ) );
		// Get user_id role.
		$user = get_user_by( 'id', $sender_id );

		if ( isset( $user->roles[0] ) && $user->roles[0] === 'administrator' ) {
			$receiver_id = Client::where( 'id', $receiver_id )->first()->user_id;
		}

		$messages = Message::where(
			function ( $query ) use ( $sender_id, $receiver_id ) {
				$query->where( 'sender_id', $sender_id )->where( 'receiver_id', $receiver_id );
			}
		)->orWhere(
			function ( $query ) use ( $sender_id, $receiver_id ) {
				$query->where( 'sender_id', $receiver_id )->where( 'receiver_id', $sender_id );
			}
		)->orderBy( 'created_at', 'asc' )->get();

		return wp_send_json_success( $messages );
	}

	public function send_message( \WP_REST_Request $request ) {
		$sender_id   = absint( $request->get_header( 'X-User-ID' ) );
		$receiver_id = absint( $request->get_param( 'receiver_id' ) );

		$message = sanitize_textarea_field( $request->get_param( 'message' ) );
		// Check if the sender is not adminstrator.
		$sender = get_user_by( 'id', $sender_id );
		if ( $sender->roles[0] !== 'administrator' ) {
			// Set receiver_id to administrator.
			$receiver_id = 1;
		} else {
			$receiver_id = Client::where( 'id', $receiver_id )->first()->user_id;
		}

		$new_message = Message::create(
			array(
				'sender_id'   => $sender_id,
				'receiver_id' => $receiver_id,
				'message'     => $message,
			)
		);

		if ( $new_message ) {
			return wp_send_json_success( $new_message );
		}

		return wp_send_json_error( 'Failed to send message' );
	}

	public function get_chat_clients( \WP_REST_Request $request ) {
		return wp_send_json_success( Client::all() );
	}
}
