<?php
/**
 * Price controller.
 *
 * @package ServiceEZ\Controllers\Services
 */

namespace ServiceEZ\Controllers\Services;

/**
 * Price controller.
 *
 * @package ServiceEZ\Controllers\Services
 */
class Price {

	/**
	 * The settings.
	 *
	 * @var array
	 */
	private $settings;

	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->settings = get_option( 'serviceez_settings' );
	}

	/**
	 * Create a price.
	 *
	 * @param array $price_data The price data.
	 * @return \Stripe\Price|null The created price or null if the key is not set.
	 */
	public function create( $price_data ) {
		// If stripe private key is not set, return null.
		if ( empty( $this->settings['payment']['stripeSecretKey'] ) ) {
			return null;
		}

		// Initialize Stripe.
		$stripe = new \Stripe\StripeClient( $this->settings['payment']['stripeSecretKey'] );

		try {
			// Create price.
			$price = $stripe->prices->create( $price_data );
			return $price;
		} catch ( \Stripe\Exception\ApiErrorException $e ) {
			return null;
		}
	}
}
