<?php

namespace ServiceEZ\Controllers\Stripe;

class Subscription {

	private $customer;

	public function __construct( $customer ) {
		$this->customer = $customer;
	}

	public function create( $params ) {
		try {
			// Create subscription items array.
			$subscription_items = array();

			// One-time items.
			$one_time_items = array();

			// Add packages.

			$package_price_data = array(
				'unit_amount' => $params['selectedPackage']['price'] * 100,
				'quantity'    => isset( $params['selectedPackage']['quantity'] ) ? $params['selectedPackage']['quantity'] : 1,
			);

			if ( ! empty( $params['selectedPackage']['price_id'] ) ) {
				$package_price_data = array(
					'price'    => $params['selectedPackage']['price_id'],
					'quantity' => isset( $params['selectedPackage']['quantity'] ) ? $params['selectedPackage']['quantity'] : 1,
				);
			}

			if ( 'recurring' === $params['selectedPackage']['pricingType'] ) {
				$subscription_items[] = $package_price_data;
			} else {
				$one_time_items[] = $package_price_data;
			}

			// Add add-ons.
			foreach ( $params['selectedAddOns'] as $selected_add_on ) {
				$addon_price_data = array(
					'unit_amount' => $selected_add_on['price'] * 100,
					'quantity'    => isset( $selected_add_on['quantity'] ) ? $selected_add_on['quantity'] : 1,
				);

				if ( ! empty( $selected_add_on['price_id'] ) ) {
					$addon_price_data = array(
						'price'    => $selected_add_on['price_id'],
						'quantity' => isset( $selected_add_on['quantity'] ) ? $selected_add_on['quantity'] : 1,
					);
				}

				if ( ! empty( $selected_add_on['pricingType'] ) && 'recurring' === $selected_add_on['pricingType'] ) {
					$subscription_items[] = $addon_price_data;
				} else {
					$one_time_items[] = $addon_price_data;
				}
			}

			// Create the subscription.
			$subscription = \Stripe\Subscription::create(
				array(
					'customer'          => $this->customer->id,
					'items'             => $subscription_items,
					'add_invoice_items' => $one_time_items,
					'payment_behavior'  => 'default_incomplete',
					'payment_settings'  => array(
						'payment_method_types'        => array( 'card' ),
						'save_default_payment_method' => 'on_subscription',
					),
					'expand'            => array( 'latest_invoice.payment_intent' ),
					'metadata'          => array(
						'package_id'   => $params['selectedPackage']['package_id'],
						'service_name' => $params['selectedPackage']['service_name'],
					),
				)
			);

			return $subscription;

		} catch ( \Exception $e ) {
			throw $e;
		}
	}
}
