<?php
/**
 * Notification model class.
 *
 * @package ServiceEZ
 * @subpackage Models
 * @since 1.0.0
 */

namespace ServiceEZ\Models;

use Prappo\WpEloquent\Database\Eloquent\Model;

/**
 * Notification model class.
 */
class Notification extends Model {
	/**
	 * The table associated with the model.
	 *
	 * @var string
	 */
	protected $table = 'serviceez_notifications';

	/**
	 * The fillable attributes.
	 *
	 * @var array
	 */
	protected $fillable = array(
		'user_id',
		'message',
		'type',
		'link',
		'read_at',
	);

	/**
	 * User relationship.
	 *
	 * @return \Prappo\WpEloquent\Database\Eloquent\Relations\BelongsTo
	 */
	public function user() {
		return $this->belongsTo( Users::class );
	}

	/**
	 * Get the created at attribute.
	 *
	 * @param string $value The value.
	 * @return string
	 */
	public function getCreatedAtAttribute( $value ) {
		return get_date_from_gmt( $value );
	}

	/**
	 * Set the created at attribute.
	 *
	 * @param string $value The value.
	 */
	public function setCreatedAtAttribute( $value ) {
		$this->attributes['created_at'] = get_gmt_from_date( $value );
	}
}
