<?php
/**
 * Service model class.
 *
 * @package ServiceEZ
 * @subpackage Models
 * @since 1.0.0
 */

namespace ServiceEZ\Models;

use Prappo\WpEloquent\Database\Eloquent\Model;

/**
 * Service model class.
 *
 * @package ServiceEZ
 * @subpackage Models
 * @since 1.0.0
 */
class Service extends Model {

	/**
	 * Table name.
	 *
	 * @var string
	 */
	protected $table = 'serviceez_services';

	/**
	 * Fillable fields.
	 *
	 * @var array
	 */
	protected $fillable = array(
		'service_name',
		'service_type',
		'data',
	);

	/**
	 * Casts.
	 *
	 * @var array
	 */
	protected $casts = array(
		'data' => 'array',
	);

	/**
	 * Orders relationship.
	 *
	 * @return \Prappo\WpEloquent\Database\Eloquent\Relations\HasMany
	 */
	public function orders() {
		return $this->hasMany( Order::class );
	}

	/**
	 * Find a service by ID.
	 *
	 * @param int $id The ID of the service to find.
	 * @return Service|null The found service or null if not found.
	 */
	public static function find( $id ) {
		$result = parent::find( $id );

		if ( $result ) {
			return array(
				'id'           => $result->id,
				'service_name' => $result->service_name,

			);
		}

		return null;
	}
}
