<?php
/**
 * ServiceEZ Routes
 *
 * Defines and registers custom API routes for the ServiceEZ using the Haruncpi\WpApi library.
 *
 * @package ServiceEZ\Routes
 */

namespace ServiceEZ\Routes;

use ServiceEZ\Libs\API\Route;
use ServiceEZ\Controllers\Services\Actions as ServicesActions;
use ServiceEZ\Controllers\Orders\Actions as OrdersActions;
use ServiceEZ\Controllers\Clients\Actions as ClientsActions;
use ServiceEZ\Controllers\Stripe\Actions as StripeActions;
use ServiceEZ\Controllers\Settings\Actions as SettingsActions;
use ServiceEZ\Controllers\Dashboard\Actions as DashboardActions;
use ServiceEZ\Controllers\Coupon\Actions as CouponActions;
use ServiceEZ\Controllers\Auth\Actions as AuthActions;
use ServiceEZ\Controllers\Notifications\Actions as NotificationsActions;
use ServiceEZ\Controllers\Messages\Actions as MessagesActions;


Route::prefix(
	SEZ_ROUTE_PREFIX,
	function ( Route $route ) {
		$services_controller = new ServicesActions();

			// Services routes.

			$route->post( '/services', array( ServicesActions::class, 'create' ) );

			$route->get( '/services', array( ServicesActions::class, 'get_all' ) );

			$route->get( '/services/{id}', array( ServicesActions::class, 'get_single' ) );

			$route->post( '/services/update/{id}', array( ServicesActions::class, 'edit' ) );

			$route->get( '/services/delete/{id}', array( ServicesActions::class, 'delete' ) );

			$route->get( '/services/share/{id}', array( $services_controller, 'get_share_service' ) );

			// Orders routes.
			$route->post( '/orders', array( OrdersActions::class, 'create' ) );
			$route->get( '/orders', array( OrdersActions::class, 'get_all' ) );
			$route->get( '/orders/{id}', array( OrdersActions::class, 'get_single' ) );
			$route->post( '/orders/update/{id}', array( OrdersActions::class, 'update' ) );
			$route->post( '/orders/delete/{id}', array( OrdersActions::class, 'delete' ) );
			$route->post( '/orders/update/status', array( OrdersActions::class, 'update_order_status' ) );
			$route->post( '/orders/{id}/pay', array( OrdersActions::class, 'process_payment' ) );
			$route->post( '/orders/{id}/confirm-payment', array( OrdersActions::class, 'confirm_payment' ) );
			$route->get( '/orders/{id}/orders', array( ClientsActions::class, 'get_client_orders' ) );
			$route->post( '/orders/{id}/send-update', array( OrdersActions::class, 'send_update_email' ) );

			// Clients routes.
			$route->post( '/clients', array( ClientsActions::class, 'create' ) );
			$route->get( '/clients', array( ClientsActions::class, 'get_all' ) );
			$route->get( '/clients/{id}', array( ClientsActions::class, 'get_single' ) );
			$route->post( '/clients/{id}', array( ClientsActions::class, 'update' ) );
			$route->post( '/clients/delete/{id}', array( ClientsActions::class, 'delete' ) );
			$route->get( '/clients/{id}/orders', array( ClientsActions::class, 'get_client_orders' ) );
			// Add this new route for the client dashboard.
			$route->get( '/client/dashboard', array( ClientsActions::class, 'get_dashboard_data' ) );

			// Stripe routes.
			$route->post( '/stripe/create-payment-intent', array( StripeActions::class, 'create_payment_intent' ) );
			$route->get( '/stripe/invoice/{invoice_id}', array( StripeActions::class, 'get_invoice' ) );
			$route->post( '/stripe/confirm-subscription', array( StripeActions::class, 'confirm_subscription' ) );

			// Settings routes.
			$route->get( '/settings', array( SettingsActions::class, 'get_settings' ) );
			$route->post( '/settings', array( SettingsActions::class, 'update_settings' ) );
			$route->post( '/settings/profile', array( SettingsActions::class, 'update_profile' ) );

			// Dashboard route.
			$route->get( '/dashboard', array( DashboardActions::class, 'get_dashboard_data' ) );

			// Allow hooks to add more custom API routes.

			// Coupon routes.
			$route->get( '/coupons', array( CouponActions::class, 'index' ) );
			$route->post( '/coupons', array( CouponActions::class, 'store' ) );
			$route->post( '/coupons/{id}', array( CouponActions::class, 'update' ) );
			$route->post( '/coupons/delete/{id}', array( CouponActions::class, 'delete' ) );
			$route->post( '/coupons/verify', array( CouponActions::class, 'verify' ) );

			// Auth routes.
			$route->post( '/auth/login', array( AuthActions::class, 'login' ) );
			$route->post( '/auth/register', array( AuthActions::class, 'register' ) );

			$route->get( '/notifications', array( NotificationsActions::class, 'get_all' ) );
			$route->post( '/notifications/{id}', array( NotificationsActions::class, 'delete' ) );
			$route->post( '/notifications/{id}/mark-as-read', array( NotificationsActions::class, 'mark_as_read' ) );
			$route->post( '/notifications/delete-all', array( NotificationsActions::class, 'delete_all' ) );

			// Messages routes.
			$route->get( '/messages/clients', array( MessagesActions::class, 'get_chat_clients' ) );
			$route->get( '/messages/chat', array( MessagesActions::class, 'get_messages' ) );
			$route->get( '/messages/chat/id/{id}', array( MessagesActions::class, 'get_messages' ) );
			$route->post( '/messages/send', array( MessagesActions::class, 'send_message' ) );


			\do_action( 'serviceez_api', $route );
	}
)->auth( array( AuthActions::class, 'check' ) );
